@@ -25,7 +25,7 @@
 
 #include <gtk/gtk.h>
 
-#include "wp-applet.h"
+#include "wp-applet-private.h"
 
 G_BEGIN_DECLS
 
